@@ -1,5 +1,5 @@
-/* $Id: hddtemp.c 5948 2008-11-03 23:59:30Z timystery $ */
-/*  Copyright 2004-2007 Fabian Nowak (timystery@arcor.de)
+/* $Id$ */
+/*  Copyright 2004-2010 Fabian Nowak (timystery@arcor.de)
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -26,6 +26,7 @@
 #include <hddtemp.h>
 #include <middlelayer.h>
 #include <types.h>
+#include <sensors-interface-common.h>
 
 /* Gtk/Glib includes */
 #include <glib.h>
@@ -69,6 +70,15 @@
 # define SINGLE_DELIMITER "|"
 #endif
 
+/* forward declaration for GCC 4.3 -Wall */
+
+void notification_suppress_messages (NotifyNotification *n, gchar *action, gpointer *data);
+void quick_message_notify (gchar *message);
+void quick_message (gchar *message);
+void read_disks_netcat (t_chip *chip);
+void remove_unmonitored_drives (t_chip *chip, gboolean *suppressmessage);
+void populate_detected_drives (t_chip *chip);
+
 #ifdef HAVE_LIBNOTIFY
 void
 notification_suppress_messages (NotifyNotification *n, gchar *action, gpointer *data)
@@ -79,7 +89,6 @@ notification_suppress_messages (NotifyNotification *n, gchar *action, gpointer *
     /* FIXME: Use channels or propagate private object or use static global variable */
 }
 
-
 void quick_message_notify (gchar *message)
 {
     NotifyNotification *nn;
@@ -148,7 +157,7 @@ gboolean quick_message_with_checkbox (gchar *message, gchar *checkboxtext) {
                                   GTK_BUTTONS_CLOSE,
                                   message);
 
-    gtk_window_set_title(GTK_WINDOW(dialog), _("Xfce 4 Sensors Plugin"));
+    gtk_window_set_title(GTK_WINDOW(dialog), _("Sensors Plugin"));
 
     checkbox = gtk_check_button_new_with_mnemonic (checkboxtext);
 
@@ -179,6 +188,7 @@ void quick_message (gchar *message)
 
 
 #ifdef HAVE_NETCAT
+
 void
 read_disks_netcat (t_chip *chip)
 {
@@ -203,7 +213,7 @@ read_disks_netcat (t_chip *chip)
     tmp = str_split (stdoutput, DOUBLE_DELIMITER);
     do {
         //g_printf ("Found token: %s\n", tmp);
-        cf = g_new(t_chipfeature, 1);
+        cf = g_new0(t_chipfeature, 1);
 
         tmp2 = g_strdup (tmp);
         tmp3 = strtok (tmp2, SINGLE_DELIMITER);
@@ -376,10 +386,10 @@ initialize_hddtemp (GPtrArray *chips, gboolean *suppressmessage)
 
     TRACE ("enters initialize_hddtemp");
 
-    chip = g_new (t_chip, 1);
+    chip = g_new0 (t_chip, 1);
 
-    chip->chip_name = (const sensors_chip_name *)
-            ( _("Hard disks"), 0, 0, _("Hard disks") );
+/*    chip->chip_name = (const sensors_chip_name *)
+            ( _("Hard disks"), 0, 0, _("Hard disks") ); */
 
     chip->chip_features = g_ptr_array_new ();
     chip->num_features = 0;
@@ -436,14 +446,16 @@ get_hddtemp_value (char* disk, gboolean *suppressmessage)
     gchar *standard_output, *standard_error;
     gchar *cmd_line, *msg_text;
 #ifndef HAVE_LIBNOTIFY
-    gchar *checktext;
+    gchar *checktext = NULL;
 #endif
     gint exit_status=0;
     double value;
     gboolean result, nevershowagain;
     GError *error;
 
+#ifdef HAVE_NETCAT
     gchar *tmp, *tmp2, *tmp3;
+#endif
 
     if (suppressmessage!=NULL)
         nevershowagain = *suppressmessage;
@@ -601,14 +613,22 @@ refresh_hddtemp (gpointer chip_feature, gpointer data)
 {
     t_chipfeature *cf;
     double value;
+    t_sensors *sensors;
+    gboolean *suppress = NULL;
 
     g_assert (chip_feature!=NULL);
 
     TRACE ("enters refresh_hddtemp");
 
+    if (data != NULL)
+    {
+        sensors = (t_sensors *) data;
+        suppress = &(sensors->suppressmessage);
+    }
+
     cf = (t_chipfeature *) chip_feature;
 
-    value = get_hddtemp_value (cf->devicename, NULL);
+    value = get_hddtemp_value (cf->devicename, suppress);
 
     /* actually, that's done in the gui part */
     g_free (cf->formatted_value);
